summaryrefslogtreecommitdiffstats
path: root/mbbsd/chc.c
diff options
context:
space:
mode:
authorscw <scw@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2004-05-16 19:30:16 +0800
committerscw <scw@63ad8ddf-47c3-0310-b6dd-a9e9d9715204>2004-05-16 19:30:16 +0800
commit280c2707ef087a032cd9a846f3fd9549e194fa19 (patch)
treed307be9b02e36ba3c132cdc73c33d04fb8eddf45 /mbbsd/chc.c
parent3d0fa7c79b4d5d08868f32f44052392d03638074 (diff)
downloadpttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar.gz
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar.bz2
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar.lz
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar.xz
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.tar.zst
pttbbs-280c2707ef087a032cd9a846f3fd9549e194fa19.zip
merge from trunk.
git-svn-id: http://opensvn.csie.org/pttbbs/branches/scw.angel@1995 63ad8ddf-47c3-0310-b6dd-a9e9d9715204
Diffstat (limited to 'mbbsd/chc.c')
-rw-r--r--mbbsd/chc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/mbbsd/chc.c b/mbbsd/chc.c
index 12aed0ad..d80cf276 100644
--- a/mbbsd/chc.c
+++ b/mbbsd/chc.c
@@ -575,14 +575,14 @@ hisplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
if (chc_lefttime < 0) {
chc_lefttime = 0;
/* to make him break out igetkey() */
chc_from.r = -2;
chc_broadcast_send(act_list, board);
}
chc_drawline(board, user1, user2, TIME_ROW);
move(1, 0);
oflush();
- switch (igetkey()) {
+ switch (igetch()) {
case 'q':
endgame = 2;
endturn = 1;
@@ -653,7 +653,7 @@ myplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
chc_drawline(board, user1, user2, TIME_ROW);
chc_movecur(chc_cursor.r, chc_cursor.c);
oflush();
- ch = igetkey();
+ ch = igetch();
chc_lefttime = CHC_TIMEOUT - (now - start_time);
if (chc_lefttime < 0)
ch = 'q';
@@ -575,14 +575,14 @@ hisplay(int s, chcusr_t *user1, chcusr_t *user2, board_t board, board_t tmpbrd)
if (chc_lefttime < 0) {
chc_lefttime = 0;
- /* to make him break out igetkey() */
+ /* to make him break out igetch() */
chc_from.r = -2;
chc_broadcast_send(act_list, board);